summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/deco16ic.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/deco16ic.cpp')
-rw-r--r--src/mame/video/deco16ic.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/deco16ic.cpp b/src/mame/video/deco16ic.cpp
index 41449bfdd05..afe0cf7e797 100644
--- a/src/mame/video/deco16ic.cpp
+++ b/src/mame/video/deco16ic.cpp
@@ -207,13 +207,13 @@ deco16ic_device::deco16ic_device(const machine_config &mconfig, const char *tag,
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void deco16ic_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void deco16ic_device::set_gfxdecode_tag(const char *tag)
{
- downcast<deco16ic_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
//-------------------------------------------------
@@ -207,13 +207,13 @@ deco16ic_device::deco16ic_device(const machine_config &mconfig, const char *tag,
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------